@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with 100 Boxes.  If not, see <http://www.gnu.org/licenses/>.
+ * along with 100 Boxes. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <glib.h>
@@ -24,6 +24,7 @@
 #include <string.h>
 #include <libxml/parser.h>
 #include <libxml/tree.h>
+#include "sound.h"
 #include "100boxes.h"
 
 static gboolean box_clicked(GtkWidget *b, GdkEventButton *event, gpointer data);
@@ -32,6 +33,7 @@ static void guide_clicked(GtkWidget *b, gpointer data);
 static void set_box_image(struct game_data *d, gint box_index, gint img_index);
 static gboolean restore_box_image(gpointer data);
 static gboolean show_end_dialog(gpointer data);
+static gchar* create_end_message(gint score);
 static void submit_score(struct game_data *d, gchar *name);
 static size_t store_post_reply(void *buffer, size_t size, size_t nmemb, void *userp);
 static void show_high_score(struct game_data *d);
@@ -55,6 +57,8 @@ int main (int argc, char **argv) {
 	d.base = box;
 	gchar file[8];
 
+	sound_init(&argc, &argv);
+
 	// Initialize OSSO and Hildon
 	osso_context = osso_initialize(OSSO_SERVICE, VERSION, TRUE, NULL);
 	if (osso_context == NULL) {
@@ -130,6 +134,7 @@ static gboolean box_clicked(GtkWidget *b, GdkEventButton *event, gpointer data)
 	if (d->s->active) {
 		d->s->last = n;
 		if ( d->s->b[n] == CLICKABLE) {
+			play_sound(SOUND_CLICK);
 			d->s->score++;
 			d->s->b[n] = d->s->score;
 			sprintf(label, "%d", d->s->score);
@@ -162,13 +167,15 @@ static gboolean box_clicked(GtkWidget *b, GdkEventButton *event, gpointer data)
 			// poss = 0; // DEBUG
 			if (poss == 0) {
 				d->s->active = FALSE;
-				if (d->s->score == 100) {
-					g_timeout_add_seconds(2, show_end_dialog, (gpointer)d);
+				if (d->s->score < 100) {
+					play_sound(SOUND_LOSE);
 				} else {
-					g_timeout_add_seconds(2, show_end_dialog, (gpointer)d);
+					play_sound(SOUND_WIN);
 				}
+				g_timeout_add_seconds(2, show_end_dialog, (gpointer)d);
 			}
 		} else {
+			play_sound(SOUND_ERROR);
 			set_box_image(d, n, ERROR);
 			d->s->active = FALSE;
 			g_timeout_add_seconds(1, restore_box_image, (gpointer)d);
@@ -191,6 +198,7 @@ void new_game(struct game_data *d) {
 	d->s->active = TRUE;
 	d->s->score = 0;
 	d->s->last = -1;
+	play_sound(SOUND_START);
 	for (i=0; i<100; i++) {
 		d->s->b[i] = CLICKABLE;
 		set_box_image(d, i, CLICKABLE);
@@ -214,9 +222,14 @@ static gboolean show_end_dialog(gpointer data) {
 	gint ans, len;
 	gchar *name, *s;
 	GtkWidget *area;
+	GtkWidget *comment;
+	GtkWidget *icon;
+	GtkWidget *caption;
 	GtkWidget *label;
 	GtkWidget *entry;
 	GtkWidget *dialog;
+	gchar file[40];
+	gchar *message;
 	struct game_data *d = (struct game_data *)data;
 	
 	dialog = gtk_dialog_new_with_buttons (NULL, GTK_WINDOW(d->window),
@@ -232,8 +245,17 @@ static gboolean show_end_dialog(gpointer data) {
 	} else {
 		gtk_window_set_title(GTK_WINDOW(dialog), "You win!");
 	}
-
 	area = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
+
+	comment = gtk_hbox_new(FALSE, 5);
+	sprintf(file, "/usr/share/pixmaps/100boxes/%d.png", d->s->score);
+	icon = gtk_image_new_from_file(file);
+	gtk_container_add(GTK_CONTAINER(comment), GTK_WIDGET(icon));	
+	message = create_end_message(d->s->score);
+	caption = gtk_label_new(message);
+	gtk_container_add(GTK_CONTAINER(comment), GTK_WIDGET(caption));
+	gtk_container_add(GTK_CONTAINER(area), GTK_WIDGET(comment));		
+
 	label = gtk_label_new("Enter your name:");
 	gtk_container_add(GTK_CONTAINER(area), GTK_WIDGET(label));
 	entry = gtk_entry_new();
@@ -249,6 +271,7 @@ static gboolean show_end_dialog(gpointer data) {
 		strcpy(name, s);
 	}
 	gtk_widget_destroy(dialog);
+	g_free(message);
 	switch (ans) {
 		case GTK_RESPONSE_ACCEPT:
 			if (len > 0) {
@@ -261,6 +284,30 @@ static gboolean show_end_dialog(gpointer data) {
 	return FALSE; // no repeat
 }
 
+static gchar* create_end_message(gint score) {
+	gint i;
+	gint l;
+	gint n = 7;
+	gint s[] = {40, 60, 75, 90, 97, 99, 100};
+	gchar* m[] = { 	"You can do better than this!", 
+			"Train some more to improve.",
+			"Nice try, the basics are there.",
+			"You are approaching the solution.",
+			"Good, you are near the goal!",
+			"Oh, you were so close!",
+			"You are a 100 Boxes champion!" };
+	gchar *msg;
+	for (i=0; i<n; i++) {
+		if (score <= s[i]) {
+			l = strlen(m[i]);
+			msg = (gchar*) g_malloc(l + 1);
+			strcpy(msg, m[i]);
+			break;
+		}
+	}
+	return msg;
+}
+
 static gboolean restore_box_image(gpointer data) {
 	struct game_data *d = (struct game_data *)data;
 	gint n = d->s->last;
@@ -411,6 +458,6 @@ static void show_high_score(struct game_data *d) {
 		xmlFreeDoc(doc);
 	}	
 	xmlCleanupParser();
-	//g_free(d->post_reply);
-	//d->post_reply = NULL;
+	g_free(d->post_reply);
+	d->post_reply = NULL;
 }
